@@ -4,23 +4,23 @@ static void *opcode_targets[256] = {
     &&TARGET_ROT_TWO,
     &&TARGET_ROT_THREE,
     &&TARGET_DUP_TOP,
+    &&TARGET_DUP_TOP_TWO,
     &&TARGET_ROT_FOUR,
     &&_unknown_opcode,
     &&_unknown_opcode,
-    &&_unknown_opcode,
     &&TARGET_NOP,
     &&TARGET_UNARY_POSITIVE,
     &&TARGET_UNARY_NEGATIVE,
     &&TARGET_UNARY_NOT,
-    &&TARGET_UNARY_CONVERT,
+    &&_unknown_opcode,
     &&_unknown_opcode,
     &&TARGET_UNARY_INVERT,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
+    &&TARGET_BINARY_MATRIX_MULTIPLY,
+    &&TARGET_INPLACE_MATRIX_MULTIPLY,
     &&_unknown_opcode,
     &&TARGET_BINARY_POWER,
     &&TARGET_BINARY_MULTIPLY,
-    &&TARGET_BINARY_DIVIDE,
+    &&_unknown_opcode,
     &&TARGET_BINARY_MODULO,
     &&TARGET_BINARY_ADD,
     &&TARGET_BINARY_SUBTRACT,
@@ -29,35 +29,35 @@ static void *opcode_targets[256] = {
     &&TARGET_BINARY_TRUE_DIVIDE,
     &&TARGET_INPLACE_FLOOR_DIVIDE,
     &&TARGET_INPLACE_TRUE_DIVIDE,
-    &&TARGET_SLICE ,
-    &&TARGET_SLICE_1,
-    &&TARGET_SLICE_2,
-    &&TARGET_SLICE_3,
+    &&TARGET_GET_LEN,
+    &&TARGET_MATCH_MAPPING,
+    &&TARGET_MATCH_SEQUENCE,
+    &&TARGET_MATCH_KEYS,
+    &&TARGET_COPY_DICT_WITHOUT_KEYS,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
-    &&TARGET_STORE_SLICE ,
-    &&TARGET_STORE_SLICE_1,
-    &&TARGET_STORE_SLICE_2,
-    &&TARGET_STORE_SLICE_3,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
-    &&TARGET_DELETE_SLICE ,
-    &&TARGET_DELETE_SLICE_1,
-    &&TARGET_DELETE_SLICE_2,
-    &&TARGET_DELETE_SLICE_3,
-    &&TARGET_STORE_MAP,
+    &&_unknown_opcode,
+    &&_unknown_opcode,
+    &&TARGET_WITH_EXCEPT_START,
+    &&TARGET_GET_AITER,
+    &&TARGET_GET_ANEXT,
+    &&TARGET_BEFORE_ASYNC_WITH,
+    &&_unknown_opcode,
+    &&TARGET_END_ASYNC_FOR,
     &&TARGET_INPLACE_ADD,
     &&TARGET_INPLACE_SUBTRACT,
     &&TARGET_INPLACE_MULTIPLY,
-    &&TARGET_INPLACE_DIVIDE,
+    &&_unknown_opcode,
     &&TARGET_INPLACE_MODULO,
     &&TARGET_STORE_SUBSCR,
     &&TARGET_DELETE_SUBSCR,
@@ -68,37 +68,37 @@ static void *opcode_targets[256] = {
     &&TARGET_BINARY_OR,
     &&TARGET_INPLACE_POWER,
     &&TARGET_GET_ITER,
-    &&_unknown_opcode,
+    &&TARGET_GET_YIELD_FROM_ITER,
     &&TARGET_PRINT_EXPR,
-    &&TARGET_PRINT_ITEM,
-    &&TARGET_PRINT_NEWLINE,
-    &&TARGET_PRINT_ITEM_TO,
-    &&TARGET_PRINT_NEWLINE_TO,
+    &&TARGET_LOAD_BUILD_CLASS,
+    &&TARGET_YIELD_FROM,
+    &&TARGET_GET_AWAITABLE,
+    &&TARGET_LOAD_ASSERTION_ERROR,
     &&TARGET_INPLACE_LSHIFT,
     &&TARGET_INPLACE_RSHIFT,
     &&TARGET_INPLACE_AND,
     &&TARGET_INPLACE_XOR,
     &&TARGET_INPLACE_OR,
-    &&TARGET_BREAK_LOOP,
-    &&TARGET_WITH_CLEANUP,
-    &&TARGET_LOAD_LOCALS,
+    &&_unknown_opcode,
+    &&_unknown_opcode,
+    &&TARGET_LIST_TO_TUPLE,
     &&TARGET_RETURN_VALUE,
     &&TARGET_IMPORT_STAR,
-    &&TARGET_EXEC_STMT,
+    &&TARGET_SETUP_ANNOTATIONS,
     &&TARGET_YIELD_VALUE,
     &&TARGET_POP_BLOCK,
-    &&TARGET_END_FINALLY,
-    &&TARGET_BUILD_CLASS,
+    &&_unknown_opcode,
+    &&TARGET_POP_EXCEPT,
     &&TARGET_STORE_NAME,
     &&TARGET_DELETE_NAME,
     &&TARGET_UNPACK_SEQUENCE,
     &&TARGET_FOR_ITER,
-    &&TARGET_LIST_APPEND,
+    &&TARGET_UNPACK_EX,
     &&TARGET_STORE_ATTR,
     &&TARGET_DELETE_ATTR,
     &&TARGET_STORE_GLOBAL,
     &&TARGET_DELETE_GLOBAL,
-    &&TARGET_DUP_TOPX,
+    &&TARGET_ROT_N,
     &&TARGET_LOAD_CONST,
     &&TARGET_LOAD_NAME,
     &&TARGET_BUILD_TUPLE,
@@ -116,11 +116,11 @@ static void *opcode_targets[256] = {
     &&TARGET_POP_JUMP_IF_FALSE,
     &&TARGET_POP_JUMP_IF_TRUE,
     &&TARGET_LOAD_GLOBAL,
+    &&TARGET_IS_OP,
+    &&TARGET_CONTAINS_OP,
+    &&TARGET_RERAISE,
     &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&TARGET_CONTINUE_LOOP,
-    &&TARGET_SETUP_LOOP,
-    &&TARGET_SETUP_EXCEPT,
+    &&TARGET_JUMP_IF_NOT_EXC_MATCH,
     &&TARGET_SETUP_FINALLY,
     &&_unknown_opcode,
     &&TARGET_LOAD_FAST,
@@ -128,43 +128,43 @@ static void *opcode_targets[256] = {
     &&TARGET_DELETE_FAST,
     &&_unknown_opcode,
     &&_unknown_opcode,
-    &&_unknown_opcode,
+    &&TARGET_GEN_START,
     &&TARGET_RAISE_VARARGS,
     &&TARGET_CALL_FUNCTION,
     &&TARGET_MAKE_FUNCTION,
     &&TARGET_BUILD_SLICE,
-    &&TARGET_MAKE_CLOSURE,
+    &&_unknown_opcode,
     &&TARGET_LOAD_CLOSURE,
     &&TARGET_LOAD_DEREF,
     &&TARGET_STORE_DEREF,
+    &&TARGET_DELETE_DEREF,
     &&_unknown_opcode,
     &&_unknown_opcode,
-    &&TARGET_CALL_FUNCTION_VAR,
     &&TARGET_CALL_FUNCTION_KW,
-    &&TARGET_CALL_FUNCTION_VAR_KW,
+    &&TARGET_CALL_FUNCTION_EX,
     &&TARGET_SETUP_WITH,
-    &&_unknown_opcode,
     &&TARGET_EXTENDED_ARG,
+    &&TARGET_LIST_APPEND,
     &&TARGET_SET_ADD,
     &&TARGET_MAP_ADD,
+    &&TARGET_LOAD_CLASSDEREF,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
+    &&TARGET_MATCH_CLASS,
+    &&_unknown_opcode,
+    &&TARGET_SETUP_ASYNC_WITH,
+    &&TARGET_FORMAT_VALUE,
+    &&TARGET_BUILD_CONST_KEY_MAP,
+    &&TARGET_BUILD_STRING,
     &&_unknown_opcode,
     &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
-    &&_unknown_opcode,
+    &&TARGET_LOAD_METHOD,
+    &&TARGET_CALL_METHOD,
+    &&TARGET_LIST_EXTEND,
+    &&TARGET_SET_UPDATE,
+    &&TARGET_DICT_MERGE,
+    &&TARGET_DICT_UPDATE,
     &&_unknown_opcode,
     &&_unknown_opcode,
     &&_unknown_opcode,
